import worker_api.client

from portal import logger

log = logger.get_logger(__name__)


class WorkerClient:
    def __init__(self, worker):
        self._worker = worker
        self._api = None

    @property
    def worker(self):
        return self._worker

    @property
    def credentials(self):
        cred = dict(
            url=self.worker.url,
            access_token=self.worker.portal_secret,
        )
        return cred

    @property
    def api(self) -> worker_api.client.WorkerClient:
        if self._api is None:
            self._api = worker_api.client.WorkerClient(**self.credentials)
        return self._api

    def execute_submission(self, submission):
        log.info(f"[WC] Executing: {submission}")
        parameters = submission.parameters
        parameters['test_files_hash'] = submission.project.config.test_files_commit_hash
        parameters['id'] = submission.id
        result = self.api.submissions.create(parameters, sid=submission.id)
        log.debug(f"[WC] Exec call result: {result}")
