import json

import pytest

from tests.rest import utils


@pytest.fixture
def student_credentials() -> str:
    return json.dumps({
        "type": "username_password",
        "identifier": "student1",
        "secret": "123456"
    })


@pytest.fixture
def teacher_credentials() -> str:
    return json.dumps({
        "type": "username_password",
        "identifier": "teacher2",
        "secret": "123123"
    })


@pytest.fixture
def teacher_secret() -> str:
    return json.dumps({
        "type": "secret",
        "identifier": "teacher1",
        "secret": "ultimate_teacher_secret"
    })


def test_project_detail_using_admin_cred(client):
    path = f'/courses/testcourse1'
    response = utils.make_request(client, path, 'get')
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_student_cred(client, student_credentials):
    path = f'/courses/testcourse1'
    response = utils.make_request(
        client, path, 'get', credentials=student_credentials)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_teacher_cred(client, teacher_credentials):
    path = f'/courses/testcourse1/projects'
    response = utils.make_request(
        client, path, 'get', credentials=teacher_credentials)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_teacher_secret(client, teacher_secret):
    path = f'/courses/testcourse1'
    response = utils.make_request(
        client, path, 'get', credentials=teacher_secret)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'
